/* sys/oric.h */

/* Contains Oric platform-specific stuff, like */
/* pointers to memory areas (video RAM etc).   */

#ifndef _SYS_ORIC_

#define _SYS_ORIC_

#include <stdlib.h>


extern char *sbrk();
extern char *brk();


/* Pointers to memory areas. */

static const char *mem[65536]=(char*)NULL;    /* The whole memory */


/* PEEK, POKE, DEEK, DOKE */

#define peek(a) ((int)mem[a])
#define deek(a) ((int)((mem[a])|(mem[a+1]<<8)))

#define poke(a,x) (mem[a]=(x))
#define doke(a,x) (mem[a]=(x&0xff),mem[a+1]=(x>>8))


/* Get and set the system flags at 0x26a. */

#define CURSOR     0x01  /* Cursor on             (ctrl-q) */
#define SCREEN     0x02  /* Printout to screen on (ctrl-s) */
#define NOKEYCLICK 0x08  /* Turn keyclick off     (ctrl-f) */
#define PROTECT    0x20  /* Protect columns 0-1   (ctrl-]) */

#define getflags()  peek(0x26a)

#define setflags(x) poke(0x26a,x)


/* Get memory size */

#define ORIC16k      1
#define ORIC48k      0

#define getmemsize() peek(0x220)


#endif /* _SYS_ORIC */

/* end of file sys/oric.h */

